@@ -8,11 +8,11 @@ from actions_lib.utils.contact_tool import get_contact_address
 
 token_mapping = {
     "ethereum": {
-        "usdc": "0xA0b86991C6218b36c1d19D4a2e9EB0cE3606EB48",  # USDC on Ethereum
+        "usdc": "0xd10519Aa03FE7Ffb95189B52B74F94Fb33E2C88a",  # USDC on Ethereum
         "usdt": "0xdAC17F958D2ee523a2206206994597C13D831ec7",  # USDT on Ethereum
     },
     "eth": {
-        "usdc": "0xA0b86991C6218b36c1d19D4a2e9EB0cE3606EB48",  # USDC on Ethereum
+        "usdc": "0xd10519Aa03FE7Ffb95189B52B74F94Fb33E2C88a",  # USDC on Ethereum
         "usdt": "0xdAC17F958D2ee523a2206206994597C13D831ec7",  # USDT on Ethereum
     },
     "bsc": {
@@ -280,7 +280,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
 
           code, res = get_contact_address(redis_client, executor, receiver, eth_w3)
           if code != 200:
-              info = {"content": f"Cannot find {receiver} on contact", "code": 420}
+              info = {"content": f"{res}", "code": 420}
               return {
                 'result': info,
                 'action': None, 
