@@ -1,5 +1,6 @@
 from typing import Tuple
 from web3 import Web3
+from ens import ENS
 
 def default_if_none(value, default="NULL"):
     return default if value is None else value
@@ -27,10 +28,12 @@ def get_contact_address(redis_client, user, contact, w3: Web3):
         if not to:
             if name.endswith(".eth"):
                 try:
-                    to = w3.ens.address(name)
+                    ns = ENS.from_web3(w3)
+                    to = ns.address(name)
                     if not to:
                         return 404, f"Cannot find {name} on ENS"
                 except Exception as e:
+                    print(f"get ens error: {e}")
                     return 500, e
             return 404, f"Cannot find {name} on contact"
     else:
